@@ -6,12 +6,13 @@ import json
 import queue
 import threading
 import time
+import logging
 import traceback
 from typing import Union
 
 from . import exception
 
-__version__ = '2.0.0'
+__version__ = '2.1.0'
 
 
 def flavor(msg):
@@ -56,7 +57,9 @@ def _find_first_key(d, keys):
     for k in keys:
         if k in d:
             return k
-    raise KeyError('No suggested keys %s in %s' % (str(keys), str(d)))
+    logging.error('No suggested keys %s in %s', str(keys), str(d))
+    # Gets the first key after the update_id one.
+    return list(d.keys())[1]
 
 
 all_content_types = [
@@ -222,8 +225,7 @@ def _dismantle_message_identifier(f):
         if len(f) == 1:
             return {'inline_message_id': f[0]}
         raise ValueError()
-    else:
-        return {'inline_message_id': f}
+    return {'inline_message_id': f}
 
 
 def _split_input_media_array(media_array):
@@ -305,7 +307,9 @@ class _BotBase:
         self._file_chunk_size = 65536
 
 
-def _strip(params, more=[]):
+def _strip(params, more=None):
+    if more is None:
+        more = []
     return {key: value for key, value in params.items() if key not in ['self'] + more}
 
 
@@ -379,7 +383,7 @@ class Bot(_BotBase):
 
                 if e.timestamp != event.timestamp:
                     raise exception.EventNotFound(event)
-                elif id(e) == id(event):
+                if id(e) == id(event):
                     self._eventq.pop(i)
                     return
 
@@ -830,7 +834,8 @@ class Bot(_BotBase):
         return self._api_request('getFile', _rectify(p))
 
     def kickChatMember(self, chat_id: Union[int, str], user_id,
-                       until_date=None):
+                       until_date: int = None,
+                       revoke_messages: bool = None):
         """ See: https://core.telegram.org/bots/api#kickchatmember """
         p = _strip(locals())
         return self._api_request('kickChatMember', _rectify(p))
@@ -866,14 +871,17 @@ class Bot(_BotBase):
         return self._api_request('restrictChatMember', _rectify(p))
 
     def promoteChatMember(self, chat_id: Union[int, str], user_id,
-                          can_change_info=None,
+                          is_anonymous=None,
+                          can_manage_chat=None,
                           can_post_messages=None,
                           can_edit_messages=None,
                           can_delete_messages=None,
-                          can_invite_users=None,
+                          can_manage_voice_chats=None,
                           can_restrict_members=None,
-                          can_pin_messages=None,
-                          can_promote_members=None):
+                          can_promote_members=None,
+                          can_change_info=None,
+                          can_invite_users=None,
+                          can_pin_messages=None):
         """ See: https://core.telegram.org/bots/api#promotechatmember """
         p = _strip(locals())
         return self._api_request('promoteChatMember', _rectify(p))
@@ -912,6 +920,26 @@ class Bot(_BotBase):
         p = _strip(locals())
         return self._api_request('exportChatInviteLink', _rectify(p))
 
+    def createChatInviteLink(self, chat_id,
+                             expire_date: int = None,
+                             member_limit: int = None):
+        """ See: https://core.telegram.org/bots/api#createchatinvitelink """
+        p = _strip(locals())
+        return self._api_request('createChatInviteLink', _rectify(p))
+
+    def editChatInviteLink(self, chat_id,
+                           invite_link: str,
+                           expire_date: int = None,
+                           member_limit: int = None):
+        """ See: https://core.telegram.org/bots/api#editchatinvitelink """
+        p = _strip(locals())
+        return self._api_request('editChatInviteLink', _rectify(p))
+
+    def revokeChatInviteLink(self, chat_id, invite_link: str):
+        """ See: https://core.telegram.org/bots/api#revokechatinvitelink """
+        p = _strip(locals())
+        return self._api_request('revokeChatInviteLink', _rectify(p))
+
     def setChatPhoto(self, chat_id: Union[int, str], photo):
         """ See: https://core.telegram.org/bots/api#setchatphoto """
         p = _strip(locals(), more=['photo'])
@@ -994,8 +1022,10 @@ class Bot(_BotBase):
         p = _strip(locals())
         return self._api_request('answerCallbackQuery', _rectify(p))
 
-    def setMyCommands(self, commands=[]):
+    def setMyCommands(self, commands=None):
         """ See: https://core.telegram.org/bots/api#setmycommands """
+        if commands is None:
+            commands = []
         p = _strip(locals())
         return self._api_request('setMyCommands', _rectify(p))
 
@@ -1008,11 +1038,12 @@ class Bot(_BotBase):
         p = _strip(locals())
         return self._api_request('setPassportDataErrors', _rectify(p))
 
-    def answerPreCheckoutQuery(self, pre_checkout_query_id, ok,
-                               error_message=None):
-        """ See: https://core.telegram.org/bots/api#answerprecheckoutquery """
+    def answerShippingQuery(self, shipping_query_id, ok,
+                            shipping_options=None,
+                            error_message=None):
+        """ See: https://core.telegram.org/bots/api#answershippingquery """
         p = _strip(locals())
-        return self._api_request('answerPreCheckoutQuery', _rectify(p))
+        return self._api_request('answerShippingQuery', _rectify(p))
 
     def answerPreCheckoutQuery(self, pre_checkout_query_id, ok,
                                error_message=None):
@@ -1254,7 +1285,7 @@ class Bot(_BotBase):
         try:
             d = dest if _isfile(dest) else open(dest, 'wb')
 
-            r = api.download((self._token, f['file_path']), preload_content=False)
+            r = api.download((self._base_url, self._token, f['file_path']), preload_content=False)
 
             while 1:
                 data = r.read(self._file_chunk_size)
@@ -1365,14 +1396,17 @@ class Bot(_BotBase):
         def relay_to_collector(update):
             key = _find_first_key(update, ['message',
                                            'edited_message',
-                                           'poll',
                                            'channel_post',
                                            'edited_channel_post',
-                                           'callback_query',
                                            'inline_query',
                                            'chosen_inline_result',
+                                           'callback_query',
                                            'shipping_query',
-                                           'pre_checkout_query'])
+                                           'pre_checkout_query',
+                                           'poll',
+                                           'poll_answer',
+                                           'my_chat_member',
+                                           'chat_member'])
             collect_queue.put(update[key])
             return update['update_id']
 
