@@ -428,7 +428,8 @@ class Bot(_BotBase):
         return await self._api_request('getFile', _rectify(p))
 
     async def kickChatMember(self, chat_id: Union[int, str], user_id,
-                             until_date=None):
+                             until_date: int = None,
+                             revoke_messages: bool = None):
         """ See: https://core.telegram.org/bots/api#kickchatmember """
         p = _strip(locals())
         return await self._api_request('kickChatMember', _rectify(p))
@@ -464,14 +465,17 @@ class Bot(_BotBase):
         return await self._api_request('restrictChatMember', _rectify(p))
 
     async def promoteChatMember(self, chat_id: Union[int, str], user_id,
-                                can_change_info=None,
+                                is_anonymous=None,
+                                can_manage_chat=None,
                                 can_post_messages=None,
                                 can_edit_messages=None,
                                 can_delete_messages=None,
-                                can_invite_users=None,
+                                can_manage_voice_chats=None,
                                 can_restrict_members=None,
-                                can_pin_messages=None,
-                                can_promote_members=None):
+                                can_promote_members=None,
+                                can_change_info=None,
+                                can_invite_users=None,
+                                can_pin_messages=None):
         """ See: https://core.telegram.org/bots/api#promotechatmember """
         p = _strip(locals())
         return await self._api_request('promoteChatMember', _rectify(p))
@@ -510,6 +514,26 @@ class Bot(_BotBase):
         p = _strip(locals())
         return await self._api_request('exportChatInviteLink', _rectify(p))
 
+    async def createChatInviteLink(self, chat_id,
+                                   expire_date: int = None,
+                                   member_limit: int = None):
+        """ See: https://core.telegram.org/bots/api#createchatinvitelink """
+        p = _strip(locals())
+        return await self._api_request('createChatInviteLink', _rectify(p))
+
+    async def editChatInviteLink(self, chat_id,
+                                 invite_link: str,
+                                 expire_date: int = None,
+                                 member_limit: int = None):
+        """ See: https://core.telegram.org/bots/api#editchatinvitelink """
+        p = _strip(locals())
+        return await self._api_request('editChatInviteLink', _rectify(p))
+
+    async def revokeChatInviteLink(self, chat_id, invite_link: str):
+        """ See: https://core.telegram.org/bots/api#revokechatinvitelink """
+        p = _strip(locals())
+        return await self._api_request('revokeChatInviteLink', _rectify(p))
+
     async def setChatPhoto(self, chat_id: Union[int, str], photo):
         """ See: https://core.telegram.org/bots/api#setchatphoto """
         p = _strip(locals(), more=['photo'])
@@ -592,8 +616,10 @@ class Bot(_BotBase):
         p = _strip(locals())
         return await self._api_request('answerCallbackQuery', _rectify(p))
 
-    async def setMyCommands(self, commands=[]):
+    async def setMyCommands(self, commands=None):
         """ See: https://core.telegram.org/bots/api#setmycommands """
+        if commands is None:
+            commands = []
         p = _strip(locals())
         return await self._api_request('setMyCommands', _rectify(p))
 
@@ -935,11 +961,15 @@ class Bot(_BotBase):
                                                'edited_message',
                                                'channel_post',
                                                'edited_channel_post',
-                                               'callback_query',
                                                'inline_query',
                                                'chosen_inline_result',
+                                               'callback_query',
                                                'shipping_query',
-                                               'pre_checkout_query'])
+                                               'pre_checkout_query',
+                                               'poll',
+                                               'poll_answer',
+                                               'my_chat_member',
+                                               'chat_member'])
 
                 callback(update[key])
             except:
@@ -1123,7 +1153,7 @@ class DelegatorBot(SpeakerBot):
 
             if id is None:
                 continue
-            elif isinstance(id, collections.Hashable):
+            if isinstance(id, collections.Hashable):
                 if id not in dict or dict[id].done():
                     c = make_coroutine_obj((self, msg, id))
 
